<?php

namespace Drupal\config_enforce_devel;

use Drupal\config_enforce\EnforcedConfigRegistry as ReadOnlyEnforcedConfigRegistry;
use Drupal\config_enforce_devel\EnforcedConfig;

/**
 * A collection of enforced configs for a given target module.
 */
class EnforcedConfigRegistry extends ReadOnlyEnforcedConfigRegistry {

  /**
   * A basic constructor method.
   */
  public function __construct(string $target_module) {
    parent::__construct($target_module);
    $this->log = $this->getLogger('config_enforce_devel::EnforcedConfigRegistry');
  }

  /**
   * Return an editable instance of the module's stored enforced configs.
   */
  public function getEditableConfig() {
    return $this->configFactory->getEditable($this->getConfigName());
  }

  /**
   * Delete this collection of enforced configs.
   */
  public function delete() {
    $config_file = EnforcedConfig::getConfigFilePath($this->getConfigName());
    $this->fileSystem->delete($config_file);
    $this->getEditableConfig()->delete();

    $module = $this->getTargetModule();
    $message = $this->t('Unregistered %name (@machine_name) as a target module.', [
      '%name' => (new TargetModuleCollection)->getTargetModuleLabel($module),
      '@machine_name' => $module,
    ]);
    $this->log->notice($message);
  }

}
